@@ -676,7 +676,6 @@ static void
 terminal_app_open_window (TerminalApp        *app,
                           TerminalWindowAttr *attr)
 {
-  TerminalTabAttr *tab_attr = NULL;
   GtkWidget       *window;
   TerminalScreen  *terminal;
   GdkScreen       *screen;
@@ -798,13 +797,6 @@ terminal_app_open_window (TerminalApp        *app,
 
   if (!attr->drop_down)
     {
-      /* don't apply other attributes to the window when reusing, just present it to user */
-      if (reuse_window)
-        {
-          gtk_window_present (GTK_WINDOW (window));
-          return;
-        }
-
       /* try to apply the geometry to the window */
       g_object_get (G_OBJECT (app->preferences), "misc-default-geometry", &geometry, NULL);
 #ifdef GDK_WINDOWING_X11
@@ -865,14 +857,9 @@ terminal_app_open_window (TerminalApp        *app,
   /* add the tabs */
   for (lp = attr->tabs; lp != NULL; lp = lp->next)
     {
-      tab_attr = lp->data;
-      terminal = terminal_screen_new (tab_attr->command,
-                                      tab_attr->directory,
-                                      tab_attr->title,
-                                      tab_attr->hold,
+      terminal = terminal_screen_new ((TerminalTabAttr *) lp->data,
                                       width,
                                       height);
-
       terminal_window_add (TERMINAL_WINDOW (window), terminal);
       terminal_screen_launch_child (terminal);
     }
@@ -886,7 +873,11 @@ terminal_app_open_window (TerminalApp        *app,
       terminal_window_set_grid_size (TERMINAL_WINDOW (window), width, height);
       terminal_screen_force_resize_window (terminal_window_get_active (TERMINAL_WINDOW (window)),
                                            GTK_WINDOW (window), width, height);
-      gtk_widget_show (window);
+
+      if (reuse_window)
+        gtk_window_present (GTK_WINDOW (window));
+      else
+        gtk_widget_show (window);
     }
 }
 
@@ -946,7 +937,7 @@ terminal_app_process (TerminalApp  *app,
         }
       else
         {
-          g_printerr ("Failed to connect to session manager: %s\n", err->message);
+          g_printerr (_("Failed to connect to session manager: %s\n"), err->message);
           g_error_free (err);
         }
     }
