@@ -46,7 +46,8 @@ typedef enum /*< enum,prefix=TERMINAL_TITLE >*/
   TERMINAL_TITLE_REPLACE,
   TERMINAL_TITLE_PREPEND,
   TERMINAL_TITLE_APPEND,
-  TERMINAL_TITLE_HIDE
+  TERMINAL_TITLE_HIDE,
+  TERMINAL_TITLE_DEFAULT
 } TerminalTitle;
 
 typedef enum /*< enum,prefix=TERMINAL_BACKGROUND >*/
