@@ -172,7 +172,9 @@ struct _TerminalScreen
 
   gchar              **custom_command;
   gchar               *custom_title;
+  gchar               *initial_title;
 
+  TerminalTitle        dynamic_title_mode;
   guint                hold : 1;
 
   guint                activity_timeout_id;
@@ -257,6 +259,7 @@ terminal_screen_init (TerminalScreen *screen)
 {
   screen->loader = NULL;
   screen->working_directory = g_get_current_dir ();
+  screen->dynamic_title_mode = TERMINAL_TITLE_DEFAULT;
   screen->session_id = ++screen_last_session_id;
 
   screen->terminal = g_object_new (TERMINAL_TYPE_WIDGET, NULL);
@@ -336,6 +339,7 @@ terminal_screen_finalize (GObject *object)
   g_strfreev (screen->custom_command);
   g_free (screen->working_directory);
   g_free (screen->custom_title);
+  g_free (screen->initial_title);
 
   (*G_OBJECT_CLASS (terminal_screen_parent_class)->finalize) (object);
 }
@@ -372,11 +376,18 @@ terminal_screen_get_property (GObject          *object,
         }
       else
         {
-          g_object_get (G_OBJECT (screen->preferences), "title-mode", &mode, NULL);
+          if (G_UNLIKELY (screen->dynamic_title_mode != TERMINAL_TITLE_DEFAULT))
+            mode = screen->dynamic_title_mode;
+          else
+            g_object_get (G_OBJECT (screen->preferences), "title-mode", &mode, NULL);
+
           if (G_UNLIKELY (mode == TERMINAL_TITLE_HIDE))
             {
               /* show the initial title if the dynamic title is set to hidden */
-              g_object_get (G_OBJECT (screen->preferences), "title-initial", &initial, NULL);
+              if (G_UNLIKELY (screen->initial_title != NULL))
+                initial = g_strdup (screen->initial_title);
+              else
+                g_object_get (G_OBJECT (screen->preferences), "title-initial", &initial, NULL);
               parsed_title = terminal_screen_parse_title (screen, initial);
               title = parsed_title;
               g_free (initial);
@@ -434,9 +445,12 @@ terminal_screen_realize (GtkWidget *widget)
 
   (*GTK_WIDGET_CLASS (terminal_screen_parent_class)->realize) (widget);
 
-  /* make sure the TerminalWidget is realized as well */
+#if !GTK_CHECK_VERSION (3, 20, 0)
+  /* make sure the TerminalWidget is realized as well
+     (produces "Drawing a gadget with negative dimensions" Gtk-WARNING) */
   if (!gtk_widget_get_realized (TERMINAL_SCREEN (widget)->terminal))
     gtk_widget_realize (TERMINAL_SCREEN (widget)->terminal);
+#endif
 
   /* connect to the "composited-changed" signal */
   screen = gtk_widget_get_screen (widget);
@@ -942,12 +956,12 @@ terminal_screen_update_colors (TerminalScreen *screen)
   GdkRGBA    cursor;
   GdkRGBA    selection;
   GdkRGBA    bold;
+  gboolean   cursor_use_default;
   gboolean   selection_use_default;
   gboolean   bold_use_default;
   guint      n = 0;
   gboolean   has_bg;
   gboolean   has_fg;
-  gboolean   has_cursor;
   gboolean   valid_palette = FALSE;
   gchar     *palette_str;
   gchar    **colors;
@@ -957,6 +971,7 @@ terminal_screen_update_colors (TerminalScreen *screen)
 
   g_object_get (screen->preferences,
                 "color-palette", &palette_str,
+                "color-cursor-use-default", &cursor_use_default,
                 "color-selection-use-default", &selection_use_default,
                 "color-bold-use-default", &bold_use_default,
                 "color-background-vary", &vary_bg,
@@ -1034,12 +1049,15 @@ terminal_screen_update_colors (TerminalScreen *screen)
     }
 
   /* cursor color */
-  has_cursor = terminal_preferences_get_color (screen->preferences, "color-cursor", &cursor);
-  vte_terminal_set_color_cursor (VTE_TERMINAL (screen->terminal), has_cursor ? &cursor : NULL);
+  if (!cursor_use_default)
+    {
+      cursor_use_default = !terminal_preferences_get_color (screen->preferences, "color-cursor-fg", &cursor);
 #if VTE_CHECK_VERSION (0, 44, 0)
-  vte_terminal_set_color_cursor_foreground (VTE_TERMINAL (screen->terminal),
-                                            has_cursor && has_bg ? &bg : NULL);
+      vte_terminal_set_color_cursor_foreground (VTE_TERMINAL (screen->terminal), cursor_use_default ? NULL : &cursor);
 #endif
+      cursor_use_default = !terminal_preferences_get_color (screen->preferences, "color-cursor", &cursor);
+      vte_terminal_set_color_cursor (VTE_TERMINAL (screen->terminal), cursor_use_default ? NULL : &cursor);
+    }
 
   /* selection color */
   if (!selection_use_default)
@@ -1540,32 +1558,29 @@ terminal_screen_set_custom_command (TerminalScreen *screen,
 
 /**
  * terminal_screen_new:
- * @command   : Command.
- * @directory : Working directory.
- * @title     : Terminal title.
- * @hold      : Whether to hold the terminal after child exits.
- * @columns   : Columns (width).
- * @rows      : Rows (height).
+ * @attr    : Terminal attributes.
+ * @columns : Columns (width).
+ * @rows    : Rows (height).
  *
  * Creates a terminal screen object.
  **/
 TerminalScreen *
-terminal_screen_new (gchar    **command,
-                     gchar     *directory,
-                     gchar     *title,
-                     gboolean   hold,
-                     glong      columns,
-                     glong      rows)
+terminal_screen_new (TerminalTabAttr *attr,
+                     glong            columns,
+                     glong            rows)
 {
   TerminalScreen *screen = g_object_new (TERMINAL_TYPE_SCREEN, NULL);
 
-  if (command != NULL)
-    terminal_screen_set_custom_command (screen, command);
-  if (directory != NULL)
-    terminal_screen_set_working_directory (screen, directory);
-  if (title != NULL)
-    terminal_screen_set_custom_title (screen, title);
-  screen->hold = hold;
+  if (attr->command != NULL)
+    terminal_screen_set_custom_command (screen, attr->command);
+  if (attr->directory != NULL)
+    terminal_screen_set_working_directory (screen, attr->directory);
+  if (attr->title != NULL)
+    terminal_screen_set_custom_title (screen, attr->title);
+  if (attr->initial_title != NULL)
+    screen->initial_title = g_strdup (attr->initial_title);
+  screen->dynamic_title_mode = attr->dynamic_title_mode;
+  screen->hold = attr->hold;
   vte_terminal_set_size (VTE_TERMINAL (screen->terminal), columns, rows);
 
   return screen;
@@ -1895,12 +1910,20 @@ terminal_screen_get_title (TerminalScreen *screen)
     return terminal_screen_parse_title (screen, screen->custom_title);
 
   vte_title = vte_terminal_get_window_title (VTE_TERMINAL (screen->terminal));
-  g_object_get (G_OBJECT (screen->preferences),
-                "title-mode", &mode,
-                "title-initial", &tmp,
-                NULL);
-  initial = terminal_screen_parse_title (screen, tmp);
-  g_free (tmp);
+
+  if (G_UNLIKELY (screen->initial_title != NULL))
+    initial = terminal_screen_parse_title (screen, screen->initial_title);
+  else
+    {
+      g_object_get (G_OBJECT (screen->preferences), "title-initial", &tmp, NULL);
+      initial = terminal_screen_parse_title (screen, tmp);
+      g_free (tmp);
+    }
+
+  if (G_UNLIKELY (screen->dynamic_title_mode != TERMINAL_TITLE_DEFAULT))
+    mode = screen->dynamic_title_mode;
+  else
+    g_object_get (G_OBJECT (screen->preferences), "title-mode", &mode, NULL);
 
   switch (mode)
     {
@@ -2264,7 +2287,7 @@ terminal_screen_set_encoding (TerminalScreen *screen,
   if (charset == NULL)
     g_get_charset (&charset);
   if (!vte_terminal_set_encoding (VTE_TERMINAL (screen->terminal), charset, NULL)) {
-    g_printerr("Failed to set encoding %s\n", charset);
+    g_printerr (_("Failed to set encoding %s\n"), charset);
   }
 }
 
